| SHI | R Documentation |
This function calculates Simple Hysteresis Index (SHI) following the description from Tsyplenkov et al. (2020)
SHI(dataframe, q, ssc, .warn = TRUE)
dataframe |
A data set object. |
q |
numeric, water discharge variable. |
ssc |
numeric, suspended sediment concentration variable. |
.warn |
logical, indicating if the warning message should be displayed. |
A numeric variable
Matthias Vanmaercke and Anatoly Tsyplenkov
Tsyplenkov A, Vanmaercke M, Golosov V, Chalov S. 2020. Suspended sediment budget and intra-event sediment dynamics of a small glaciated mountainous catchment in the Northern Caucasus. Journal of Soils and Sediments 20 (8): 3266–3281 DOI: 10.1007/s11368-020-02633-z
library(dplyr)
data(djan)
output_table <- hydro_events(dataframe = djan,
q = discharge,
datetime = time,
window = 21)
output_table %>%
filter(he == 2) %>%
SHI(q = discharge, ssc = SS)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.